@@ -102,7 +102,6 @@ static const gchar *test_lines[] = {
   "fakesrc name=100 fakesink name=101 silent=true 100. ! 101.", /* linking with named reference on both sides */
   "fakesrc ! 1__dentity ! fakesink silent=true",        /* using a freshly registered element type */
   "fakesrc ! tee name=t  t.src_12 ! queue ! fakesink  t.src_3 ! queue ! fakesink",
-  "fakesrc name=foo name=fin  fin. ! fakesink", /* testing assignments are executed in correct order (left-to-right) */
   "( fakesrc ) ! fakesink",     /* ghostPad creation on-the-fly, infix notation link */
   "( fakesrc name=dasrc ) dasrc. ! fakesink",   /* ghostPad creation on-the-fly, named link */
 /*  "(name=mabin fakesrc) mabin. ! fakesink", FIXME: linking to named bin does not work yet */
@@ -112,6 +111,10 @@ static const gchar *test_lines[] = {
   "fakesrc : video/x-all : fakesink",   /* linking all matching pads with filter */
   "fakesrc ! video/x-all : fakesink",   /* linking all matching pads with filter */
   "fakesrc : video/x-all ! fakesink",   /* linking all matching pads with filter */
+  "fakesrc ! audio/x-opus, channel-mapping=(int)<0, 1> ! fakesink silent=true", /* array in capsfilter */
+  "fakesrc ! audio/x-opus, channel-mapping=(int)<0,\\ 1> ! fakesink silent=true",       /* array in capsfilter with escaped spaces */
+  "fakesrc ! capsfilter caps=\"audio/x-opus, channel-mapping=(int)<0, 1>\" ! fakesink silent=true",     /* array in explicit capsfilter */
+  "fakesrc ! capsfilter caps=\"audio/x-opus, channel-mapping=(int)<0,\\ 1>\" ! fakesink silent=true",   /* array in explicit capsfilter with escaped spaces */
   NULL
 };
 
@@ -366,8 +369,6 @@ static const gchar *expected_failures[] = {
   "fakesrc ! fakesink s.ch1",
   /* unlinked src/sink URI */
   "http://eff.org fakesrc ! fakesink",
-  /* catch assignments evaluated in wrong order */
-  "fakesrc name=ss name=st  ss. ! fakesink",
   /* unbalanced brackets */
   "(", ")", ")  (",
   /* END: */
@@ -379,6 +380,7 @@ GST_START_TEST (expected_to_fail_pipes)
   const gchar **s;
 
   for (s = expected_failures; *s != NULL; s++) {
+    GST_ERROR ("Running %s", *s);
     expected_fail_pipe (*s);
   }
 }
